# Welcome to OmnivoreX

[OmnivoreX](https://github.com/yazdipour/OmnivoreX) is a Text User Interface (TUI) for the [Omnivore](https://omnivore.app/).

On the left side, you can see the list of your Omnivore articles. On the right side, you can see the content of the selected article.

In the footer, you can see shortcuts to navigate between articles.

## Shortcuts

| Key | Description |
| --- | --- |
| `j` / `d` | Move down |
| `k` / `u` | Move up |
| `h` | Move to the top |
| `g` | Move to the bottom |
| `a` | Archive / Unarchive |
| `r` | Refresh |
| `t` | Toggle theme |
| `s` | Settings |
| `q` | Quit |
